package com.your_domain.your_product.main;

import com.jdbaccess.db.JDBaccess;
import com.jdbaccess.db.DataSource;
import com.jdbaccess.exception.ApplicationException;

/**
 * Example for starting JDBAccess with data source
 */
public class ExampleJDBAccess {
  private String dataSourceName = "scott"; // your data source name (e.g. scott)
  private String dbName = "orcl";          // your database name (Oracle: sid (see service_name in tnsnames.ora: e.g. "orcl"); MySQL: dataBaseName)
  private String dbHost = "linux";         // your database host name
  private int dbPort = 1521;               // your database port name (e.g. 1521 for Oracle or 3306 fpr mysql)
  private String dbUser = "scott";         // your database user (e.g. scott)
  private String dbUserPW = "tiger";       // your database user password (e.g. tiger)
  
  private boolean debugMode = true;        // if true, some debug info is automatically logged to standard output

  public void start() throws ApplicationException {
    DataSource exampleDS = new DataSource(dataSourceName, dbHost, dbPort, dbName, dbUser, dbUserPW);
    addConnectionInitCommands(exampleDS);
    JDBaccess.setDataSource(exampleDS, debugMode);
    JDBaccess.start();
  }
  
  public void end() {
    try {
      JDBaccess.end();
      System.exit(-1);
    } catch (ApplicationException e) {
      System.out.println(e.toString());
    }
  }  

  public void setDebugMode(boolean debugMode) {
    this.debugMode = debugMode;  
  }
  
  /**
   * Sql init commands which are performed when getConnection() on this data source is called
   * These are example init commands. Please comment them out if you don't need them.
   * They are performed every time you get a new transaction/connection.
   * @param ds dataSource
   */
  private void addConnectionInitCommands(DataSource ds) {
    // example Oracle init string
    String initCommand = "alter session set current_schema = " + dbUser;
    ds.addConnectionInitSQLString(initCommand);
  }
}
